==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skgbankmodelertest/skgtestbankandaccount.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * This file is a test script.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgtestmacro.h"
#include "skgbankincludes.h"

/**
 * The main function of the unit test
 * @param argc the number of arguments
 * @param argv the list of arguments
 */
int main(int argc, char** argv)
{
        Q_UNUSED(argc);
        Q_UNUSED(argv);

        //Init test
        SKGINITTEST(true);
        //============================================================================
        //Init
        {
                //Test bank1 document
                SKGDocumentBank document1;
                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
                SKGError err;
                {
                        //Scrope of the transaction
                        SKGBEGINTRANSACTION(document1, "BANK_T1", err);

                        //Creation bank1
                        SKGBankObject bank1(&document1);
                        SKGTESTERROR("BANK:setName",bank1.setName("CREDIT COOP"), true);
                        SKGTESTERROR("BANK:setIcon",bank1.setIcon("credit cooperatif"), true);
                        SKGTESTERROR("BANK:setNumber",bank1.setNumber("111111"), true);
                        SKGTESTERROR("BANK:save", bank1.save(), true);
                        SKGTEST("BANK:getIcon",bank1.getIcon(), "credit cooperatif");
                        SKGTEST("BANK:getNumber",bank1.getNumber(), "111111");

                        SKGBankObject bank11(bank1); //For coverage
                        SKGTEST("BANK:comparison",(bank11==bank1), true);
                        SKGBankObject bank12=bank1; //For coverage
                        SKGTEST("BANK:comparison",(bank12==bank1), true);

                        //Creation account1
                        SKGAccountObject account1;
                        SKGTESTERROR("BANK:addAccount",bank1.addAccount(account1), true);
                        SKGTESTERROR("ACCOUNT:setName",account1.setName("Courant steph"), true);
                        SKGTESTERROR("ACCOUNT:setNumber",account1.setNumber("12345P"), true);
                        SKGTESTERROR("ACCOUNT:setAgencyNumber",account1.setAgencyNumber("99999"), true);
                        SKGTESTERROR("ACCOUNT:setAgencyAddress",account1.setAgencyAddress("10 rue Albert CAMUS\n31000 TOULOUSE"), true);
                        SKGTESTERROR("ACCOUNT:setType",account1.setType(SKGAccountObject::CREDITCARD), true);
                        SKGTESTERROR("ACCOUNT:setComment",account1.setComment("bla bla"), true);
                        SKGTESTERROR("ACCOUNT:save",account1.save(), true);
                        SKGTEST("ACCOUNT:getNumber",account1.getNumber(), "12345P");
                        SKGTEST("ACCOUNT:getAgencyNumber",account1.getAgencyNumber(), "99999");
                        SKGTEST("ACCOUNT:getAgencyAddress",account1.getAgencyAddress(), "10 rue Albert CAMUS\n31000 TOULOUSE");
                        SKGTEST("ACCOUNT:getType",account1.getType(), SKGAccountObject::CREDITCARD);
                        SKGTEST("ACCOUNT:getComment",account1.getComment(), "bla bla");

                        SKGAccountObject account11(account1); //For coverage
                        SKGTEST("BANK:comparison",(account11==account1), true);
                        SKGAccountObject account12((SKGNamedObject) account1);//For coverage
                        SKGTEST("BANK:comparison",(account12==account1), true);
                        SKGAccountObject account13((SKGObjectBase) account1);//For coverage
                        SKGTEST("BANK:comparison",(account13==account1), true);

                        //Creation bank2
                        SKGBankObject bank2(&document1);
                        SKGTESTERROR("BANK:setName",bank2.setName("NEF"), true);
                        SKGTESTERROR("BANK:save", bank2.save(), true);

                        //Creation account2
                        SKGAccountObject account2;
                        SKGTESTERROR("BANK:addAccount",bank2.addAccount(account2), true);
                        SKGTESTERROR("ACCOUNT:setName",account2.setName("Courant steph"), true);
                        SKGTESTERROR("ACCOUNT:setNumber",account2.setNumber("98765A"), true);
                        SKGTESTERROR("ACCOUNT:save",account2.save(false), false);

                        SKGAccountObject account3;
                        SKGTESTERROR("BANK:addAccount",bank2.addAccount(account3), true);
                        SKGTESTERROR("ACCOUNT:setName",account3.setName("Courant vero"), true);
                        SKGTESTERROR("ACCOUNT:setNumber",account3.setNumber("98765A"), true);
                        SKGTESTERROR("ACCOUNT:save",account3.save(), true);

                        QStringList oResult;
                        SKGTESTERROR("BANK:getDistinctValues", SKGServices::getDistinctValues(&document1, "bank", "t_name", oResult), true);
                        SKGTEST("BANK:oResult.size", oResult.size(), 2);

                        SKGTESTERROR("BANK:getDistinctValues", SKGServices::getDistinctValues(&document1, "account", "t_name", oResult), true);
                        SKGTEST("BANK:oResult.size", oResult.size(), 2);

                        SKGObjectBase::SKGListSKGObjectBase oAccountList;
                        SKGTESTERROR("BANK:getAccounts",bank1.getAccounts(oAccountList), true);
                        SKGTEST("ACCOUNT:count", oAccountList.count(), 1);

                        SKGTESTERROR("BANK:getAccounts",bank2.getAccounts(oAccountList), true);
                        SKGTEST("ACCOUNT:count", oAccountList.count(), 1);

                        //Modification account1
                        SKGBankObject tmpBank;
                        SKGTESTERROR("ACCOUNT:getBank",account3.getBank(tmpBank), true);
                        SKGTEST("BANK:tmpBank==bank2", (tmpBank==bank2), true);
                        SKGTESTERROR("ACCOUNT:setBank",account3.setBank(bank1), true);
                        SKGTESTERROR("ACCOUNT:getBank",account3.getBank(tmpBank), true);
                        SKGTEST("BANK:tmpBank==bank2", (tmpBank==bank1), true);
                        SKGTESTERROR("ACCOUNT:save",account3.save(), true);

                        SKGTESTERROR("BANK:getAccounts",bank1.getAccounts(oAccountList), true);
                        SKGTEST("ACCOUNT:count", oAccountList.count(), 2);

                        SKGTESTERROR("BANK:getAccounts",bank2.getAccounts(oAccountList), true);
                        SKGTEST("ACCOUNT:count", oAccountList.count(), 0);

                        SKGTEST("ACCOUNT:isClosed", account3.isClosed(), false);
                        SKGTESTERROR("ACCOUNT:setClosed",account3.setClosed(true), true);
                        SKGTEST("ACCOUNT:isClosed", account3.isClosed(), true);
                        SKGTESTERROR("ACCOUNT:save",account3.save(), true);

                        SKGTESTERROR("DOC:dump",document1.dump(DUMPALL), true);

                }
        }

        //End test
        SKGENDTEST();
}

==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/skgbankmodelertest/skgtestbankandaccount.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * This file is a test script.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgtestmacro.h"
#include "skgbankincludes.h"

/**
 * The main function of the unit test
 * @param argc the number of arguments
 * @param argv the list of arguments
 */
int main(int argc, char** argv)
{
        Q_UNUSED(argc);
        Q_UNUSED(argv);

        //Init test
        SKGINITTEST(true);
        //============================================================================
        //Init
        {
                //Test bank1 document
                SKGDocumentBank document1;
                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
                SKGError err;
                {
                        //Scrope of the transaction
                        SKGBEGINTRANSACTION(document1, "BANK_T1", err);

                        //Creation bank1
                        SKGBankObject bank1(&document1);
                        SKGTESTERROR("BANK:setName",bank1.setName("CREDIT COOP"), true);
                        SKGTESTERROR("BANK:setIcon",bank1.setIcon("credit cooperatif"), true);
                        SKGTESTERROR("BANK:setNumber",bank1.setNumber("111111"), true);
                        SKGTESTERROR("BANK:save", bank1.save(), true);
                        SKGTEST("BANK:getIcon",bank1.getIcon(), "credit cooperatif");
                        SKGTEST("BANK:getNumber",bank1.getNumber(), "111111");

                        SKGBankObject bank11(bank1); //For coverage
                        SKGTEST("BANK:comparison",(bank11==bank1), true);
                        SKGBankObject bank12=bank1; //For coverage
                        SKGTEST("BANK:comparison",(bank12==bank1), true);

                        //Creation account1
                        SKGAccountObject account1;
                        SKGTESTERROR("BANK:addAccount",bank1.addAccount(account1), true);
                        SKGTESTERROR("ACCOUNT:setName",account1.setName("Courant steph"), true);
                        SKGTESTERROR("ACCOUNT:setNumber",account1.setNumber("12345P"), true);
                        SKGTESTERROR("ACCOUNT:setAgencyNumber",account1.setAgencyNumber("99999"), true);
                        SKGTESTERROR("ACCOUNT:setAgencyAddress",account1.setAgencyAddress("10 rue Albert CAMUS\n31000 TOULOUSE"), true);
                        SKGTESTERROR("ACCOUNT:setType",account1.setType(SKGAccountObject::CREDITCARD), true);
                        SKGTESTERROR("ACCOUNT:setComment",account1.setComment("bla bla"), true);
                        SKGTESTERROR("ACCOUNT:save",account1.save(), true);
                        SKGTEST("ACCOUNT:getNumber",account1.getNumber(), "12345P");
                        SKGTEST("ACCOUNT:getAgencyNumber",account1.getAgencyNumber(), "99999");
                        SKGTEST("ACCOUNT:getAgencyAddress",account1.getAgencyAddress(), "10 rue Albert CAMUS\n31000 TOULOUSE");
                        SKGTEST("ACCOUNT:getType",account1.getType(), SKGAccountObject::CREDITCARD);
                        SKGTEST("ACCOUNT:getComment",account1.getComment(), "bla bla");

                        SKGAccountObject account11(account1); //For coverage
                        SKGTEST("BANK:comparison",(account11==account1), true);
                        SKGAccountObject account12((SKGNamedObject) account1);//For coverage
                        SKGTEST("BANK:comparison",(account12==account1), true);
                        SKGAccountObject account13((SKGObjectBase) account1);//For coverage
                        SKGTEST("BANK:comparison",(account13==account1), true);

                        //Creation bank2
                        SKGBankObject bank2(&document1);
                        SKGTESTERROR("BANK:setName",bank2.setName("NEF"), true);
                        SKGTESTERROR("BANK:save", bank2.save(), true);

                        //Creation account2
                        SKGAccountObject account2;
                        SKGTESTERROR("BANK:addAccount",bank2.addAccount(account2), true);
                        SKGTESTERROR("ACCOUNT:setName",account2.setName("Courant steph"), true);
                        SKGTESTERROR("ACCOUNT:setNumber",account2.setNumber("98765A"), true);
                        SKGTESTERROR("ACCOUNT:save",account2.save(false), false);

                        SKGAccountObject account3;
                        SKGTESTERROR("BANK:addAccount",bank2.addAccount(account3), true);
                        SKGTESTERROR("ACCOUNT:setName",account3.setName("Courant vero"), true);
                        SKGTESTERROR("ACCOUNT:setNumber",account3.setNumber("98765A"), true);
                        SKGTESTERROR("ACCOUNT:save",account3.save(), true);

                        QStringList oResult;
                        SKGTESTERROR("BANK:getDistinctValues", SKGServices::getDistinctValues(&document1, "bank", "t_name", oResult), true);
                        SKGTEST("BANK:oResult.size", oResult.size(), 2);

                        SKGTESTERROR("BANK:getDistinctValues", SKGServices::getDistinctValues(&document1, "account", "t_name", oResult), true);
                        SKGTEST("BANK:oResult.size", oResult.size(), 2);

                        SKGObjectBase::SKGListSKGObjectBase oAccountList;
                        SKGTESTERROR("BANK:getAccounts",bank1.getAccounts(oAccountList), true);
                        SKGTEST("ACCOUNT:count", oAccountList.count(), 1);

                        SKGTESTERROR("BANK:getAccounts",bank2.getAccounts(oAccountList), true);
                        SKGTEST("ACCOUNT:count", oAccountList.count(), 1);

                        //Modification account1
                        SKGBankObject tmpBank;
                        SKGTESTERROR("ACCOUNT:getBank",account3.getBank(tmpBank), true);
                        SKGTEST("BANK:tmpBank==bank2", (tmpBank==bank2), true);
                        SKGTESTERROR("ACCOUNT:setBank",account3.setBank(bank1), true);
                        SKGTESTERROR("ACCOUNT:getBank",account3.getBank(tmpBank), true);
                        SKGTEST("BANK:tmpBank==bank2", (tmpBank==bank1), true);
                        SKGTESTERROR("ACCOUNT:save",account3.save(), true);

                        SKGTESTERROR("BANK:getAccounts",bank1.getAccounts(oAccountList), true);
                        SKGTEST("ACCOUNT:count", oAccountList.count(), 2);

                        SKGTESTERROR("BANK:getAccounts",bank2.getAccounts(oAccountList), true);
                        SKGTEST("ACCOUNT:count", oAccountList.count(), 0);

                        SKGTEST("ACCOUNT:isBookmarked", account3.isBookmarked(), false);
                        SKGTESTERROR("ACCOUNT:bookmark",account3.bookmark(true), true);
                        SKGTEST("ACCOUNT:isBookmarked", account3.isBookmarked(), true);

			SKGTEST("ACCOUNT:isClosed", account3.isClosed(), false);
                        SKGTESTERROR("ACCOUNT:setClosed",account3.setClosed(true), true);
                        SKGTEST("ACCOUNT:isClosed", account3.isClosed(), true);

			SKGTESTERROR("ACCOUNT:save",account3.save(), true);

                        SKGTESTERROR("DOC:dump",document1.dump(DUMPALL), true);
                }
        }

        //End test
        SKGENDTEST();
}
